# scRNA-seq

```{toctree}
:maxdepth: 1

notebooks/harmonization
notebooks/scvi_in_R
notebooks/tabula_muris
notebooks/scarches_scvi_tools
notebooks/query_hlca_knn
notebooks/seed_labeling
notebooks/linear_decoder
notebooks/AutoZI_tutorial
notebooks/cellassign_tutorial
notebooks/amortized_lda
notebooks/scVI_DE_worm
```
